#!/bin/sh

temphome=$(mktemp -d)
tempdatadir=$temphome/.local/share

mkdir -p $tempdatadir

env \
	HOME=$temphome XDG_DATA_HOME=$tempdatadir \
	ATUIN_DB_URI="postgres://$PGUSER:$PGPASSWORD@$PGHOST:$PGPORT/$PGDATABASE" \
	$@
